@@ -1,6 +1,13 @@
-/* demo/grph1/slpack/slpk04.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -18,7 +25,7 @@ static real c_b14 = .05f;
 static integer c__0 = 0;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Main program */ int MAIN__(void)
 {
@@ -31,7 +38,7 @@ static integer c__0 = 0;
     address a__1[3];
     integer i__1[3];
     real r__1, r__2, r__3, r__4;
-    char ch__1[11], ch__2[1];
+    char ch__1[13], ch__2[3];
 
     /* Builtin functions */
     integer s_wsle(cilist *), do_lio(integer *, integer *, char *, ftnlen), 
@@ -40,7 +47,7 @@ static integer c__0 = 0;
 
     /* Local variables */
     static integer iws;
-    extern /* Character */ VOID csgi_(char *, ftnlen, integer *);
+    extern /* Character */ VOID usgi_(char *, ftnlen, integer *);
     extern /* Subroutine */ int sgcls_(void), sgfrm_(void);
     static real xmaxf, ymaxf;
     extern /* Subroutine */ int slrat_(real *, real *), sgopn_(integer *), 
@@ -65,7 +72,7 @@ static integer c__0 = 0;
     xmaxf = 26.f;
     ymaxf = 18.5f;
     slform_(&xmaxf, &ymaxf);
-/* <-- Ūѻ礭 */
+/* <-- */
     slrat_(&xmaxf, &ymaxf);
     sglset_("LFULL", &c_true, (ftnlen)5);
     sgfrm_();
@@ -78,11 +85,11 @@ static integer c__0 = 0;
     sgplu_(&c__5, x, y);
 /* Writing concatenation */
     i__1[0] = 5, a__1[0] = "15cm ";
-    csgi_(ch__2, (ftnlen)1, &c__194);
-    i__1[1] = 1, a__1[1] = ch__2;
+    usgi_(ch__2, (ftnlen)3, &c__194);
+    i__1[1] = 3, a__1[1] = ch__2;
     i__1[2] = 5, a__1[2] = " 15cm";
-    s_cat(ch__1, a__1, i__1, &c__3, (ftnlen)11);
-    sgtxzu_(&c_b9, &c_b9, ch__1, &c_b14, &c__0, &c__0, &c__3, (ftnlen)11);
+    s_cat(ch__1, a__1, i__1, &c__3, (ftnlen)13);
+    sgtxzu_(&c_b9, &c_b9, ch__1, &c_b14, &c__0, &c__0, &c__3, (ftnlen)13);
     sgcls_();
     return 0;
 } /* MAIN__ */
