@@ -1,6 +1,13 @@
-/* demo/math1/vralib/vral01.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -15,7 +22,7 @@ static real c_b56 = 0.f;
 static logical c_true = TRUE_;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Main program */ int MAIN__(void)
 {
@@ -28,9 +35,9 @@ static logical c_true = TRUE_;
 
     /* Local variables */
     static real ry[10];
-    extern /* Subroutine */ doublereal rfna_();
+    extern real rfna_();
     extern /* Subroutine */ int vrfna_(real *, real *, integer *, integer *, 
-	    integer *, U_fp), vrinc_(real *, real *, integer *, integer *, 
+	    integer *, R_fp), vrinc_(real *, real *, integer *, integer *, 
 	    integer *, real *), vrfct_(real *, real *, integer *, integer *, 
 	    integer *, real *), vrcon_(real *, real *, integer *, integer *, 
 	    integer *, real *), vrset_(real *, real *, integer *, integer *, 
@@ -95,7 +102,7 @@ static logical c_true = TRUE_;
     do_fio(&c__1, " LIST OF RY : ", (ftnlen)14);
     do_fio(&c__10, (char *)&ry[0], (ftnlen)sizeof(real));
     e_wsfe();
-    vrfna_(ry, ry, &c__10, &c__1, &c__1, (U_fp)rfna_);
+    vrfna_(ry, ry, &c__10, &c__1, &c__1, (R_fp)rfna_);
     s_wsfe(&io___11);
     do_fio(&c__1, " AFTER CALLING VRFNA(RY,RY,10,1,1,RFNA)", (ftnlen)39);
     e_wsfe();
@@ -142,7 +149,7 @@ static logical c_true = TRUE_;
     do_fio(&c__1, " LIST OF RY : ", (ftnlen)14);
     do_fio(&c__10, (char *)&ry[0], (ftnlen)sizeof(real));
     e_wsfe();
-    vrfna_(ry, ry, &c__10, &c__1, &c__1, (U_fp)rfna_);
+    vrfna_(ry, ry, &c__10, &c__1, &c__1, (R_fp)rfna_);
     s_wsfe(&io___23);
     do_fio(&c__1, " AFTER CALLING VRFNA(RY,RY,10,1,1,RFNA)", (ftnlen)39);
     e_wsfe();
@@ -165,7 +172,7 @@ static logical c_true = TRUE_;
 } /* MAIN__ */
 
 /* ----------------------------------------------------------------------- */
-doublereal rfna_(real *r__)
+real rfna_(real *r__)
 {
     /* System generated locals */
     real ret_val;
