@@ -1,6 +1,13 @@
-/* src/grph1/szpack/szstni.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -12,7 +19,7 @@ static integer c__100 = 100;
 /* ----------------------------------------------------------------------- */
 /*     TONE PATTERN ATTRIBUTE */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int szstni_0_(int n__, integer *itpat)
 {
@@ -31,16 +38,23 @@ static integer c__100 = 100;
 	    ftnlen, ftnlen, ftnlen);
     static logical lhard;
     static integer icpat[100];
-    static logical lcl2tn, lclatr;
-    extern /* Subroutine */ int sglget_(char *, logical *, ftnlen), msgdmp_(
-	    char *, char *, char *, ftnlen, ftnlen, ftnlen);
+    static logical lcl2tn;
+    static integer ibgcli;
+    static logical lclatr;
+    extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen), sglget_(
+	    char *, logical *, ftnlen), msgdmp_(char *, char *, char *, 
+	    ftnlen, ftnlen, ftnlen);
     static logical lmonof;
     extern /* Subroutine */ int swqclc_(logical *);
-    static logical lsoftf, ltnatr;
-    static integer itpatz;
+    static logical lsoftf;
+    static integer itcliy;
+    static logical ltnatr;
+    static integer itpaty, itpatz;
     extern /* Subroutine */ int szcltn_(integer *, integer *), swqtnc_(
-	    logical *), szstmd_(logical *), sztits_(integer *), sztitz_(
-	    integer *);
+	    logical *);
+    static integer itpnmy;
+    extern /* Subroutine */ int szstmd_(logical *), sztits_(integer *), 
+	    sztitz_(integer *);
 
     switch(n__) {
 	case 1: goto L_szqtni;
@@ -48,6 +62,7 @@ static integer c__100 = 100;
 
 /*     / INITIALIZE / */
     itpatz = *itpat;
+    sgiget_("IBGCLI", &ibgcli, (ftnlen)6);
     if (lfrst) {
 	swqtnc_(&ltnatr);
 	swqclc_(&lclatr);
@@ -68,28 +83,24 @@ static integer c__100 = 100;
 	}
 	lfrst = FALSE_;
     }
-/*     / SOFT FILL OR HARD FILL / */
+/*     / SOFT FILL OR HARD FILL (FORCE TO SOFT FILL) / */
     sglget_("LSOFTF", &lsoftf, (ftnlen)6);
+    lhard = FALSE_;
     if (lsoftf) {
-	lhard = FALSE_;
     } else {
-	if (ltnatr) {
-	    lhard = TRUE_;
-	} else {
-	    lhard = FALSE_;
-	    if (lmsg) {
-		msgdmp_("W", "SZSTNI", "HARD FILL IS NOT SUPPORTED.", (ftnlen)
-			1, (ftnlen)6, (ftnlen)27);
-		lmsg = FALSE_;
-	    }
+	lsoftf = TRUE_;
+	lhard = FALSE_;
+	if (lmsg) {
+	    msgdmp_("W", "SZSTNI", "HARD FILL IS OBSOLETE.SOFT FILLED", (
+		    ftnlen)1, (ftnlen)6, (ftnlen)33);
+	    lmsg = FALSE_;
 	}
     }
-    szstmd_(&lhard);
 /*     / COLOR TO TONE CONVERSION / */
     if (lmonof) {
 	lp = itpatz % 1000;
 	lc = itpatz / 1000;
-	if (lp == 999) {
+	if (lp == 999 && lc != ibgcli) {
 	    if (1 <= lc && lc <= 100) {
 		if (icpat[lc - 1] >= 0) {
 		    itpatz = icpat[lc - 1];
@@ -111,16 +122,30 @@ static integer c__100 = 100;
 	    }
 	}
     }
+    itcliy = itpatz / 1000;
+    itpnmy = itpatz % 1000;
+    if (itcliy == ibgcli) {
+	itpaty = itpnmy;
+    } else {
+	if (itcliy == 0) {
+	    itcliy = 1;
+	}
+	itpaty = itpnmy + itcliy * 1000;
+    }
+    if (itpnmy == 999) {
+	lhard = TRUE_;
+    }
+    szstmd_(&lhard);
     if (lhard) {
 	sztitz_(&itpatz);
     } else {
-	sztits_(&itpatz);
+	sztits_(&itpaty);
     }
     return 0;
 /* ----------------------------------------------------------------------- */
 
 L_szqtni:
-    *itpat = itpatz;
+    *itpat = itpaty;
     return 0;
 } /* szstni_ */
 
