@@ -1,6 +1,13 @@
-/* src/grph2/ucpack/ucxady.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -15,7 +22,7 @@ static logical c_false = FALSE_;
 /* ----------------------------------------------------------------------- */
 /*     UCXADY : PLOT DATE AXIS */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int ucxady_(char *cside, integer *jd0, integer *nd, ftnlen 
 	cside_len)
@@ -86,6 +93,10 @@ static logical c_false = FALSE_;
 	iml = ndmon_(&iyi, &moi);
 	if (idi < iml - id / 2 && idi % id == 0 || idi == iml) {
 	    ++nn;
+	    if (nn > 100) {
+		msgdmp_("E", "UCXADY", "WORKING AREA IS NOT ENOUGH.", (ftnlen)
+			1, (ftnlen)6, (ftnlen)27);
+	    }
 	    ux[nn - 1] = (real) i__;
 	    ici__1.icierr = 0;
 	    ici__1.icirnum = 1;
@@ -103,9 +114,6 @@ static logical c_false = FALSE_;
 	msgdmp_("W", "UCXADY", "THERE IS NO TICKMARK / LABEL.", (ftnlen)1, (
 		ftnlen)6, (ftnlen)29);
 	return 0;
-    } else if (nn > 100) {
-	msgdmp_("E", "UCXADY", "WORKING AREA IS NOT ENOUGH.", (ftnlen)1, (
-		ftnlen)6, (ftnlen)27);
     }
 /* Writing concatenation */
     i__2[0] = 6, a__1[0] = "ICENTX";
