@@ -1,6 +1,13 @@
-/* src/grph2/ulpack/ulylog.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -11,22 +18,22 @@ static real c_b13 = 1.f;
 static logical c_true = TRUE_;
 static integer c__10 = 10;
 static integer c__1 = 1;
-static real c_b28 = 10.f;
-static integer c__4 = 4;
+static real c_b29 = 10.f;
+static integer c__3 = 3;
 static integer c__2 = 2;
 static integer c__16 = 16;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int ulylog_(char *cside, integer *nlbl, integer *nticks, 
 	ftnlen cside_len)
 {
     /* System generated locals */
-    address a__1[4], a__2[2];
-    integer i__1, i__2, i__3, i__4[4], i__5[2];
+    address a__1[3], a__2[2];
+    integer i__1, i__2, i__3, i__4[3], i__5[2];
     real r__1, r__2;
-    char ch__1[1], ch__2[1], ch__3[7];
+    char ch__1[7];
     icilist ici__1;
 
     /* Builtin functions */
@@ -37,7 +44,7 @@ static integer c__16 = 16;
 	     char **, integer *, integer *, ftnlen);
 
     /* Local variables */
-    static char ch[16*50];
+    static char ch[18*50];
     static integer ib;
     static real bl[10];
     static integer nb;
@@ -49,10 +56,10 @@ static integer c__16 = 16;
     static integer nbs, nbt;
     static real sgn, uyt[50], yyy;
     extern /* Subroutine */ int gnge_(real *, real *, integer *);
-    extern /* Character */ VOID csgi_(char *, ftnlen, integer *);
     static logical loff;
     extern /* Subroutine */ int gnle_(real *, real *, integer *);
     static char cfmt[16];
+    extern real usgi_(integer *);
     extern logical lrgt_(real *, real *);
     extern integer lenz_(char *, ftnlen);
     static real ymin;
@@ -69,6 +76,7 @@ static integer c__16 = 16;
     static real bymax;
     static integer ipmax;
     static real bymin;
+    static logical lsfnt;
     static integer itype;
     extern /* Subroutine */ int vrgnn_(real *, integer *, integer *);
     static integer jtype;
@@ -82,14 +90,14 @@ static integer c__16 = 16;
     extern /* Subroutine */ int uzcget_(char *, char *, ftnlen, ftnlen), 
 	    gnrset_(void), sgqwnd_(real *, real *, real *, real *), ulylbl_(
 	    real *, integer *, integer *), sgswnd_(real *, real *, real *, 
-	    real *), uyplbl_(char *, integer *, real *, char *, integer *, 
-	    integer *, ftnlen, ftnlen), sgstrf_(void), uzlget_(char *, 
-	    logical *, ftnlen), uzrget_(char *, real *, ftnlen), uypaxs_(char 
-	    *, integer *, ftnlen), uyptmk_(char *, integer *, real *, integer 
-	    *, ftnlen);
+	    real *), swlget_(char *, logical *, ftnlen), uyplbl_(char *, 
+	    integer *, real *, char *, integer *, integer *, ftnlen, ftnlen), 
+	    sgstrf_(void), uzlget_(char *, logical *, ftnlen), uzrget_(char *,
+	     real *, ftnlen), uypaxs_(char *, integer *, ftnlen), uyptmk_(
+	    char *, integer *, real *, integer *, ftnlen);
 
     /* Fortran I/O blocks */
-    static icilist io___35 = { 0, chr, 0, "(I8)", 8, 1 };
+    static icilist io___36 = { 0, chr, 0, "(I8)", 8, 1 };
 
 
 /*     CSIDE : 'L','R','U' */
@@ -132,6 +140,7 @@ static integer c__16 = 16;
     sgiget_("IRST", &irst, (ftnlen)4);
     gllget_("LEPSL", &lepsl, (ftnlen)5);
     sglget_("LCNTL", &lcntl, (ftnlen)5);
+    swlget_("SYSFONT", &lsfnt, (ftnlen)7);
     gllset_("LEPSL", &c_true, (ftnlen)5);
     gnsave_();
 /*     SMALL TICKS */
@@ -139,9 +148,9 @@ static integer c__16 = 16;
     bs[*nticks] = 10.f;
     i__1 = *nticks + 1;
     gnsblk_(bs, &i__1);
-    r__1 = dabs(ymax);
+    r__1 = abs(ymax);
     gnle_(&r__1, &bymax, &ipmax);
-    r__1 = dabs(ymin);
+    r__1 = abs(ymin);
     gnge_(&r__1, &bymin, &ipmin);
     nbs = 0;
     i__1 = ipmax;
@@ -159,7 +168,7 @@ static integer c__16 = 16;
 		msgdmp_("E", "ULYLOG", "TOO MANY TICKS.", (ftnlen)1, (ftnlen)
 			6, (ftnlen)15);
 	    }
-	    uy1[nbs - 1] = sgn * bs[ib - 1] * pow_ri(&c_b28, &ip);
+	    uy1[nbs - 1] = sgn * bs[ib - 1] * pow_ri(&c_b29, &ip);
 L100:
 	    ;
 	}
@@ -167,9 +176,9 @@ L100:
 /*     LARGE LABELS AND TICKS */
     i__2 = nb + 1;
     gnsblk_(bl, &i__2);
-    r__1 = dabs(ymax);
+    r__1 = abs(ymax);
     gnle_(&r__1, &bymax, &ipmax);
-    r__1 = dabs(ymin);
+    r__1 = abs(ymin);
     gnge_(&r__1, &bymin, &ipmin);
     nbl = 0;
     nbt = 0;
@@ -186,20 +195,20 @@ L100:
 	    }
 	    if (ib == 1) {
 		++nbt;
-		uyt[nbt - 1] = sgn * pow_ri(&c_b28, &ip);
+		uyt[nbt - 1] = sgn * pow_ri(&c_b29, &ip);
 	    }
 	    ++nbl;
 	    if (nbl > 50) {
 		msgdmp_("E", "ULYLOG", "TOO MANY LABELS.", (ftnlen)1, (ftnlen)
 			6, (ftnlen)16);
 	    }
-	    uy2[nbl - 1] = sgn * bl[ib - 1] * pow_ri(&c_b28, &ip);
+	    uy2[nbl - 1] = sgn * bl[ib - 1] * pow_ri(&c_b29, &ip);
 	    if (itype <= 2) {
 		if (jtype == 0 && ib != 1) {
 		    ici__1.icierr = 0;
 		    ici__1.icirnum = 1;
-		    ici__1.icirlen = 16;
-		    ici__1.iciunit = ch + (nbl - 1 << 4);
+		    ici__1.icirlen = 18;
+		    ici__1.iciunit = ch + (nbl - 1) * 18;
 		    ici__1.icifmt = "(I1)";
 		    s_wsfi(&ici__1);
 		    i__3 = (integer) bl[ib - 1];
@@ -209,50 +218,50 @@ L100:
 		    if (jtype == 1 && nb != 1) {
 			ici__1.icierr = 0;
 			ici__1.icirnum = 1;
-			ici__1.icirlen = 16;
-			ici__1.iciunit = ch + (nbl - 1 << 4);
-			ici__1.icifmt = "(I1,A1)";
+			ici__1.icirlen = 18;
+			ici__1.iciunit = ch + (nbl - 1) * 18;
+			ici__1.icifmt = "(I1,A3)";
 			s_wsfi(&ici__1);
 			i__3 = (integer) bl[ib - 1];
 			do_fio(&c__1, (char *)&i__3, (ftnlen)sizeof(integer));
-			csgi_(ch__2, (ftnlen)1, &iychr);
-			*(unsigned char *)&ch__1[0] = *(unsigned char *)&
-				ch__2[0];
-			do_fio(&c__1, ch__1, (ftnlen)1);
+			r__1 = usgi_(&iychr);
+			do_fio(&c__1, (char *)&r__1, (ftnlen)sizeof(real));
 			e_wsfi();
 		    } else {
-			s_copy(ch + (nbl - 1 << 4), " ", (ftnlen)16, (ftnlen)
+			s_copy(ch + (nbl - 1) * 18, " ", (ftnlen)18, (ftnlen)
 				1);
 		    }
-		    s_wsfi(&io___35);
+		    s_wsfi(&io___36);
 		    do_fio(&c__1, (char *)&ip, (ftnlen)sizeof(integer));
 		    e_wsfi();
 		    cladj_(chr, (ftnlen)8);
 		    if (lcntl) {
+/*              IF(LSFNT) THEN */
 /* Writing concatenation */
-			i__4[0] = 2, a__1[0] = "10";
-			csgi_(ch__1, (ftnlen)1, &isup);
-			i__4[1] = 1, a__1[1] = ch__1;
-			i__4[2] = lenz_(chr, (ftnlen)8), a__1[2] = chr;
-			csgi_(ch__2, (ftnlen)1, &irst);
-			i__4[3] = 1, a__1[3] = ch__2;
-			s_cat(ch + ((nbl - 1 << 4) + 2), a__1, i__4, &c__4, (
+			i__4[0] = 5, a__1[0] = "10\\^{";
+			i__4[1] = lenz_(chr, (ftnlen)8), a__1[1] = chr;
+			i__4[2] = 1, a__1[2] = "}";
+			s_cat(ch + ((nbl - 1) * 18 + 4), a__1, i__4, &c__3, (
 				ftnlen)14);
+/*              ELSE */
+/*                CH(NBL)(3:16)='10'//CSGI(ISUP)//CHR(1:LENZ(CHR)) */
+/*     +            //CSGI(IRST) */
+/*              END IF */
 		    } else {
 /* Writing concatenation */
 			i__5[0] = 1, a__2[0] = "E";
 			i__5[1] = 8, a__2[1] = chr;
-			s_cat(ch + ((nbl - 1 << 4) + 1), a__2, i__5, &c__2, (
+			s_cat(ch + ((nbl - 1) * 18 + 3), a__2, i__5, &c__2, (
 				ftnlen)15);
 		    }
-		    cladj_(ch + (nbl - 1 << 4), (ftnlen)16);
+		    cladj_(ch + (nbl - 1) * 18, (ftnlen)18);
 		}
 	    } else {
 		if (jtype == 0 && ib != 1) {
 		    ici__1.icierr = 0;
 		    ici__1.icirnum = 1;
-		    ici__1.icirlen = 16;
-		    ici__1.iciunit = ch + (nbl - 1 << 4);
+		    ici__1.icirlen = 18;
+		    ici__1.iciunit = ch + (nbl - 1) * 18;
 		    ici__1.icifmt = "(I1)";
 		    s_wsfi(&ici__1);
 		    i__3 = (integer) bl[ib - 1];
@@ -260,10 +269,10 @@ L100:
 		    e_wsfi();
 		} else {
 		    uzcget_("CYFMT", cfmt, (ftnlen)5, (ftnlen)16);
-		    r__2 = (r__1 = uy2[nbl - 1], dabs(r__1));
-		    chval_(cfmt, &r__2, ch + (nbl - 1 << 4), (ftnlen)16, (
-			    ftnlen)16);
-		    cladj_(ch + (nbl - 1 << 4), (ftnlen)16);
+		    r__2 = (r__1 = uy2[nbl - 1], abs(r__1));
+		    chval_(cfmt, &r__2, ch + (nbl - 1) * 18, (ftnlen)16, (
+			    ftnlen)18);
+		    cladj_(ch + (nbl - 1) * 18, (ftnlen)18);
 		}
 	    }
 L201:
@@ -275,9 +284,9 @@ L201:
 	for (ib = 1; ib <= i__1; ++ib) {
 /* Writing concatenation */
 	    i__5[0] = 1, a__2[0] = "-";
-	    i__5[1] = 16, a__2[1] = ch + (ib - 1 << 4);
+	    i__5[1] = 18, a__2[1] = ch + (ib - 1) * 18;
 	    s_cat(chw, a__2, i__5, &c__2, (ftnlen)16);
-	    s_copy(ch + (ib - 1 << 4), chw, (ftnlen)16, (ftnlen)16);
+	    s_copy(ch + (ib - 1) * 18, chw, (ftnlen)18, (ftnlen)16);
 /* L301: */
 	}
     }
@@ -292,10 +301,10 @@ L201:
 /* Writing concatenation */
     i__5[0] = 6, a__2[0] = "LABELY";
     i__5[1] = 1, a__2[1] = cside;
-    s_cat(ch__3, a__2, i__5, &c__2, (ftnlen)7);
-    uzlget_(ch__3, &label, (ftnlen)7);
+    s_cat(ch__1, a__2, i__5, &c__2, (ftnlen)7);
+    uzlget_(ch__1, &label, (ftnlen)7);
     if (label) {
-	uyplbl_(cside, &c__1, uy2, ch, &c__16, &nbl, (ftnlen)1, (ftnlen)16);
+	uyplbl_(cside, &c__1, uy2, ch, &c__16, &nbl, (ftnlen)1, (ftnlen)18);
     }
     gllset_("LEPSL", &lepsl, (ftnlen)5);
     gnrset_();
