@@ -1,6 +1,13 @@
-/* src/math2/odelib/odrk4s.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -9,7 +16,7 @@
 /*    Runge-Kutta Stepper. */
 /*                                                 Oct. 5, 1990  S.Sakai */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int odrk4s_(integer *n, S_fp fcn, real *t, real *dt, real *
 	epsl, real *x, real *work)
@@ -34,7 +41,7 @@
 
     /* Parameter adjustments */
     work_dim1 = *n;
-    work_offset = 1 + work_dim1 * 1;
+    work_offset = 1 + work_dim1;
     work -= work_offset;
     --x;
 
@@ -61,12 +68,12 @@
     i__1 = *n;
     for (i__ = 1; i__ <= i__1; ++i__) {
 	work[i__ + work_dim1 * 3] = x[i__] - work[i__ + (work_dim1 << 1)];
-	xscal = (r__1 = x[i__], dabs(r__1)) + (r__2 = dt2 * work[i__ + 
-		work_dim1], dabs(r__2)) + tiny;
+	xscal = (r__1 = x[i__], abs(r__1)) + (r__2 = dt2 * work[i__ + 
+		work_dim1], abs(r__2)) + tiny;
 /* Computing MAX */
-	r__2 = errmax, r__3 = (r__1 = work[i__ + work_dim1 * 3] / xscal, dabs(
+	r__2 = errmax, r__3 = (r__1 = work[i__ + work_dim1 * 3] / xscal, abs(
 		r__1));
-	errmax = dmax(r__2,r__3);
+	errmax = max(r__2,r__3);
 /* L200: */
     }
     errmax /= *epsl;
